import hashlib
import requests
from TempMail_Generator.config import Config

class Email:
    def __init__(self, email: str, token: str):
        self.EMAIL = email
        self.TOKEN = token
        self.HASH = hashlib.md5(f"[{self.EMAIL}]:[{self.TOKEN}]".encode()).hexdigest()

    def read_inbox(self):
        response = requests.get(Config.TEMP_READ_MAIL_API % self.EMAIL, headers=Config.TEMP_MAIL_HEADERS)
        try:
            response.raise_for_status()
        except Exception as e:
            raise RuntimeError(f"ReadInboxError: {e}")
        return response.json()

class APIProcess:
    @staticmethod
    def __get_req():
        Config.TEMP_MAIL_HEADERS['X-RapidAPI-Key'] = Config.API_KEYS[Config.KEY_INDEX]
        try:
            response = requests.post(Config.TEMP_NEW_MAIL_API, headers=Config.TEMP_MAIL_HEADERS)
            # response.raise_for_status()
        except requests.RequestException as e:
            raise RuntimeError(f"GenerateEmailError: {e}")
        return response.json()

    @staticmethod
    def generate_email():
        Config.load()
        if not Config.API_KEYS or Config.API_KEYS[0].startswith("YOUR_API_KEY"):
            raise RuntimeError(f"Missing API Key! Obtain from: {Config.OBTAIN_API_FROM}")
        data = APIProcess.__get_req()
        while not data.get("email"):
            Config.KEY_INDEX += 1
            if Config.KEY_INDEX >= len(Config.API_KEYS):
                raise RuntimeError(f"ResponseError: {data}")
            data = APIProcess.__get_req()
        email_obj = Email(data['email'], data['token'])
        Config.Emails.append(email_obj)
        return email_obj



import json
import argparse
import webbrowser
from TempMail_Generator.server import Backend,Config

def main():
    parser = argparse.ArgumentParser(
        description="Temporary Email Generator (Flask-based)",
        epilog="Example: python main.py --host 0.0.0.0 --port 8080 --no-browser"
    )
    parser.add_argument("--host", default="127.0.0.1", help="Host to bind the server to (default: 127.0.0.1)")
    parser.add_argument("--port", type=int, default=5000, help="Port number (default: 5000)")
    parser.add_argument("--no-browser", action="store_true", help="Disable auto-opening the browser")
    parser.add_argument("--config", action="store_true", help="Edit configuration file (config.json)")

    args = parser.parse_args()

    if args.config:
        print("Current configuration:")
        print(json.dumps(Config.CONFIG, indent=4))
        key_list = input("Enter new API keys (space separated) or leave empty to keep: ").strip()
        if key_list:
            Config.CONFIG["rapid_api_keys"] += [k.strip() for k in key_list.split(" ")]
            Config.CONFIG["rapid_api_keys"] = list(set(Config.CONFIG["rapid_api_keys"]))
    
        new_host = input(f"API Host [{Config.CONFIG['api_host']}]: ").strip()
        if new_host:
            Config.CONFIG["api_host"] = new_host
    
        new_base = input(f"API Base URL [{Config.CONFIG['api_base_url']}]: ").strip()
        if new_base:
            Config.CONFIG["api_base_url"] = new_base
            
        Config.save_config()
        print("Configuration updated!")
        return

    if not args.no_browser:
        webbrowser.open(f"http://{args.host}:{args.port}/")
    Backend().run(debug=False, host=args.host, port=args.port)

if __name__ == "__main__":
    main()



import json
from pathlib import Path

class Config:
    Emails = []
    # to obtain api keys: https://rapidapi.com/calvinloveland335703-0p6BxLYIH8f/api/temp-mail44
    OBTAIN_API_FROM = "https://rapidapi.com/calvinloveland335703-0p6BxLYIH8f/api/temp-mail44"
    CONFIG_PATH = Path("config.json")
    DEFAULT_CONFIG = {
        "rapid_api_keys": [
            "YOUR_API_KEY_1",
            "YOUR_API_KEY_2",
            "YOUR_API_KEY_3"
        ],
        "api_host": "temp-mail44.p.rapidapi.com",
        "api_base_url": "https://temp-mail44.p.rapidapi.com/api/v3"
    }

    CONFIG = DEFAULT_CONFIG
    API_KEYS = None
    KEY_INDEX = 0
    TEMP_MAIL_HEADERS = None
    TEMP_NEW_MAIL_API = None
    TEMP_READ_MAIL_API = None

    @staticmethod
    def load():
        if not Config.CONFIG_PATH.exists():
            Config.CONFIG_PATH.write_text(json.dumps(Config.DEFAULT_CONFIG, indent=4))

        Config.CONFIG = json.loads(Config.CONFIG_PATH.read_text())
        Config.API_KEYS = Config.CONFIG["rapid_api_keys"]
        Config.KEY_INDEX = 0
        Config.TEMP_MAIL_HEADERS = {
            "content-type": "application/json",
            "X-RapidAPI-Key": Config.API_KEYS[Config.KEY_INDEX],
            "X-RapidAPI-Host": Config.CONFIG["api_host"]
        }

        Config.TEMP_NEW_MAIL_API = f"{Config.CONFIG['api_base_url']}/email/new"
        Config.TEMP_READ_MAIL_API = f"{Config.CONFIG['api_base_url']}/email/%s/messages"
    
    @staticmethod
    def save_config():
        return Config.CONFIG_PATH.write_text(json.dumps(Config.CONFIG, indent=4))



from flask import Flask, jsonify, render_template, request
from flask_cors import CORS
from TempMail_Generator.process import APIProcess, Config
import pkg_resources

class Backend:
    APP = Flask(__name__, static_folder="static", template_folder=pkg_resources.resource_filename('TempMail_Generator', 'templates'))

    def __init__(self):
        CORS(self.APP)
        Config.load()

        # Add routes
        self.APP.add_url_rule('/', view_func=self.index)
        self.APP.add_url_rule('/generate', view_func=self.generate, methods=['POST'])
        self.APP.add_url_rule('/inbox', view_func=self.inbox, methods=['POST'])

        # Global error handler
        @self.APP.errorhandler(Exception)
        def handle_error(e):
            print(f"[ERROR] {type(e).__name__}: {e}", flush=True)
            return jsonify({"error": str(e)}), 500

    def index(self):
        return render_template("index.html"), 200

    def generate(self):
        try:
            # TEMP: Comment out actual email generation for debugging
            email = APIProcess.generate_email()
            _ret = {"email": email.EMAIL, "token": email.HASH}

            # Dummy response to test fetch
            # _ret = {"email": "test@example.com", "token": "12345"}
            print(f"[LOG] {_ret}", flush=True)
            return jsonify(_ret), 200

        except Exception as e:
            print(f"[EXCEPTION in /generate] {e}", flush=True)
            return jsonify({"error": str(e)}), 500

    def inbox(self):
        token = request.get_json() or {}
        print(f"[POST ReadInbox] {token}", flush=True)
        token = token.get('tk')
        if not token:
            return jsonify({"messages": []}), 404
        email = next((e for e in Config.Emails if e.HASH == token), None)
        if email is None:
            _ret = {"messages": []}
        else:
            _ret = {"messages": list(reversed(email.read_inbox()))}
        print(f"[LOG] {_ret}", flush=True)
        return jsonify(_ret), 200

    def run(self, debug, host, port):
        print(f"[STARTING BACKEND] http://{host}:{port}")
        self.APP.run(debug=debug, host=host, port=port)



from TempMail_Generator.server import Backend
from TempMail_Generator.process import APIProcess,Config


class TempMailGenerator:
    def __init__(self):
        Config.load()

    def add_api(key_list:list[str]|str,new_host:str=None,new_base:str=None):
        if isinstance(key_list,str):
            key_list = [key_list]
        Config.CONFIG["rapid_api_keys"] += [k.strip() for k in key_list.split(" ")]
        Config.CONFIG["rapid_api_keys"] = list(set(Config.CONFIG["rapid_api_keys"]))

        if new_host:
            Config.CONFIG["api_host"] = new_host.strip()

        if new_base:
            Config.CONFIG["api_base_url"] = new_base.strip()
        Config.save_config()

    def generate():
        return APIProcess.generate_email()
    
    def start_server(self,debug:bool = False, host:str=None, port:int=None):
        Backend().run(debug=debug, host=host, port=port)



from setuptools import setup, find_packages

__author__ = "Jo0x01"
__pkg_name__ = "TempMail_Generator"
__version__ = "1.0.3"
__desc__ = """A lightweight temporary email generator built with Flask (Python) and a modern frontend.
It allows you to quickly generate disposable email addresses, view incoming messages, and refresh your inbox automatically."""

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name=__pkg_name__,
    version=__version__,
    packages=find_packages(),   # Use find_packages to automatically include subpackages
    include_package_data=True,  # Include non-Python files specified in MANIFEST.in
    package_data={
        # Include all files in the templates folder inside your package
        __pkg_name__: ["templates/*", "templates/**/*"],  
    },
    license='MIT',
    description=__desc__,
    author=__author__,
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/jo0x01/TempMail-Generator',
    keywords=["tempmail", "tmail", "email", "mail", "temporary-email", "disposable-mail"],
    install_requires=['flask','flask-core', 'requests'],
    entry_points={
        'console_scripts': [
            'temp-mail = TempMail_Generator.__main__:main',
            'tmail = TempMail_Generator.__main__:main',
            'create-mail = TempMail_Generator.__main__:main',
            'generate-mail = TempMail_Generator.__main__:main',
            'gt-mail = TempMail_Generator.__main__:main',
            'gtmail = TempMail_Generator.__main__:main',
        ]
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)
